  function [D,U,X1,X2]=adsig(N1,N2,A1,A2,A,GRAPH)
 %
 % function [D,U,X1,X2]=adsig(N1,N2,A1,A2,A,GRAPH)
 % Basic signals: unit sample, unit step, exponential sequence,
 %		 rectangular sequence
 %
 % N1,N2 - number of values	 D  - unit impulse
 % A1,A2 - exponential constants  U  - unit step
 % A - multiplication constant	 X1 - exponential sequence
 %				 X2 - rectangular sequence
 % GRAPH - graph display
 %	    (for GRAPH=1)
 %
   if exist('N')==0                      % Default values
     N1=20; N2=20; A1=0.98; A2=0.9; A=2; GRAPH=1; end
     n1=-N1/2:N1/2-1; n2=-N2/2:N2/2-1; XX1=zeros(N1+2, N2+1);
 %
 % Signals definition
 %
   D=zeros(N1,N2); D(1,1)=1; D=fftshift(D);
   U=zeros(N1,N2); U(1:N1/2,N2/2+1:N2)=ones(N1/2,N2/2);
   X1=A*A1.^(n1'*ones(1,N2)).*A2.^(ones(N1,1)*n2); XX1(2:N1+1,2:N2+1)=X1;
   X2=zeros(N1,N2); X2(N1/2:N1/2+2, N2/2:N2/2+2)= ones(3);
 %
   if GRAPH~=1, return, end		% Result display
 %
   delete(get(0,'children'))  
   figure('name','ADSIG','units','normal','position',[0.24,0.11,0.7,0.8]); 
   
   axes('position',[0.1 0.55 0.38 0.4],'xtick',[],'ytick',[],'box','on');   
      title('UNIT SAMPLE')
   axes('position',[0.14 0.58 0.30 0.34],'xtick',[],'ytick',[],'box','on'); 
      mesh(D); grid on
      axis([0 21 0 21 0 1]); axis on;

   axes('position',[0.55 0.55 0.38 0.4],'xtick',[],'ytick',[],'box','on');   
      title('UNIT STEP');
   axes('position',[0.59 0.58 0.30 0.34],'xtick',[],'ytick',[],'box','on');
      mesh(U); view(-130,30); grid on
      axis([0 21 0 21 0 1]); axis on;

   axes('position',[0.1 0.05 0.38 0.4],'xtick',[],'ytick',[],'box','on');   
      title('EXPONENTIAL SEQUENCE');   
   axes('position',[0.14 0.08 0.30 0.34],'xtick',[],'ytick',[],'box','on');
      mesh(XX1); view(60,30); grid on
      axis([0 22 0 22 0 8]); axis on;

   axes('position',[0.55 0.05 0.38 0.4],'xtick',[],'ytick',[],'box','on');   
      title('RECTANGULAR SEQUENCE');
   axes('position',[0.59 0.08 0.30 0.34],'xtick',[],'ytick',[],'box','on');
      mesh(X2); grid on
      axis([0 21 0 21 0 1]); axis on;
 
 