   function [x,X]=aspecest(N,M,om0,GRAPH)
 %
 % function [x,X]=aspecest(N,M,om0,GRAPH)
 % Basic window functions and their magnitude spectra (rectangular,
 %				       Bartlett, Hanning, Hamming)
 %
 % N - number of window values	  x - windowed sequence
 % M - number of frequency points  X - magnitude windowed sequence spectrum
 % om0-frequency component	  GRAPH - graph display (for GRAPH=1)
 %
   if exist('N')==0                 % Default values
     N=32;om0=1; M=128; GRAPH=1; end
   nc=-10:N+8; n=0:(N-1);
   fdft=[0:N-1]/N*2*pi; f=[0:(M-1)]/M*2*pi;
   NC1=round((N+1)/(2*pi)*om0); NC2=N+1-NC1;
 %
 % windowed sequence definition and its spectrum estimation
 %
   xc=cos(om0*nc); x=cos(om0*n);
   XC=zeros(1,N); XC(NC1)=pi; XC(NC2)=pi;
   XDFT=fft(x); X=fft(x,M);
 %
 % if GRAPH~=1, return, end	    % Result display
 %
   delete(get(0,'children'))  
   figure('name','ASPECEST','units','normal','position',[0.24,0.11,0.7,0.8]); 

   subplot(221)
      stem(nc,xc,'MarkerSize',3,'Color','k'); grid on
      axis([-10 40.05 -1.3 1.3]);
      xlabel('Time');
      title('GIVEN SEQUENCE');
   
   subplot(222);
      stem(fdft, XC,'MarkerSize',3,'Color','k'); grid on
      axis([0 2*pi -0.5 4]); 
      xlabel('Frequency');
      title('THEORETICAL SPECTRUM');
  
   subplot(223);   
      stem(x,'MarkerSize',3,'Color','k'); grid on
      axis([-10 40.05 -1.3 1.3]);  
      xlabel('Time'); 
      title('WINDOWED SEQUENCE');
  
   subplot(224);
      plot(f,20*log10(abs(X))); hold on;
      plot(fdft,20*log10(abs(XDFT)),'o'); hold off; grid on;
      axis([0 2*pi -30 30]); 
      xlabel('Frequency');
      title('SPECTRUM ESTIMATION');
 