   function [w,W]=awindow(N,M,GRAPH)
 %
 % function [w,W]=awindow(N,M,GRAPH)
 % Basic window functions and their magnitude spectra (rectangular,
 %				       Bartlett, Hanning, Hamming)
 %
 % N - number of window values	  w - window values
 % M - number of frequency points  W - magnitude windows spectra
 %				  GRAPH - graph display (for GRAPH=1)
 %
   if exist('N')==0                 % Default values
     N=32;M=128; GRAPH=1; end
   f=[0:(M-1)]/M; 
 
   w=[boxcar(N) bartlett(N) hanning(N) hamming(N)];
   W=fft(w,M);
   for j=1:4
     W(:,j)=abs(W(:,j))/abs(W(1,j));
   end 

   if GRAPH~=1, return, end	    % Result display
 %
 
   delete(get(0,'children'))  
   figure('name','AWINDOWA','units','normal','position',[0.24,0.11,0.7,0.8]); 
 
   subplot(221)
      stem(w(:,1)); grid on
      axis([0 N 0 1]);
      xlabel('TIME'); 
      title('RECTANGULAR WINDOW');

   subplot(222)  
      plot(f,20*log10(W(:,1)+eps)); grid on
      axis([0 1 -70 0]);
      xlabel('Frequency'); 
      title('Magnitude Spectrum');

   subplot(223)
      stem(w(:,2)); grid on
      axis([0 N 0 1]);
      xlabel('TIME'); 
      title('Bartlett window'); 
  
   subplot(224)
      plot(f,20*log10(W(:,2)+eps));  grid on
      axis([0 1 -70 0]);
      xlabel('Frequency'); 
      title('MAGNITUDE SPECTRUM');
      

   figure('name','AWINDOWB','units','normal','position',[0.29,0.01,0.7,0.8]); 
     
   subplot(221)
      stem(w(:,3)); grid on
      axis([0 N 0 1]);
      xlabel('Time'); 
      title('HANNING WINDOW'); 

   subplot(222)
      plot(f,20*log10(W(:,3)+eps)); grid on
      axis([0 1 -70 0]);
      xlabel('Frequency'); 
      title('MAGNITUDE SPECTRUM');

   subplot(223)
      stem(w(:,4)); grid on
      axis([0 N 0 1]);
      xlabel('Time'); 
      title('HAMMING WINDOW'); 

   subplot(224)
      plot(f,20*log10(W(:,4)+eps)); grid on
      axis([0 1 -70 0]);
      xlabel('Frequency');
      title('MAGNITUDE SPECTRUM');

